@@ -6,7 +6,7 @@ use Mojo::JSON;
 use Mojo::Util 'deprecated';
 use constant DEBUG => $ENV{MOJO_OPENAPI_DEBUG} || 0;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 sub EXCEPTION { +{errors => [{message => 'Internal server error.', path => '/'}], status => 500} }
 sub NOT_FOUND { +{errors => [{message => 'Not found.',             path => '/'}], status => 404} }
@@ -31,7 +31,7 @@ sub register {
   }
 
   $self->{log_level} = $ENV{MOJO_OPENAPI_LOG_LEVEL} || $config->{log_level} || 'warn';
-  $self->{renderer} = $config->{renderer} || sub { Mojo::JSON::encode_json($_[1]) };
+  $self->{renderer} = $config->{renderer} || \&_render_json;
   $self->_validator->schema($api_spec->data)->coerce($config->{coerce} // 1);
   $self->_add_routes($app, $api_spec, $config);
 }
@@ -175,6 +175,7 @@ sub _render {
   my $v = $self->_validator;
 
   $c->stash->{format} ||= 'json';
+  delete $options->{encoding};
 
   if (my @errors = $v->validate_response($c, $c->openapi->spec, $status, $res)) {
     $self->_log($c, '>>>', \@errors);
@@ -186,6 +187,11 @@ sub _render {
   }
 }
 
+sub _render_json {
+  $_[0]->res->headers->content_type('application/json;charset=UTF-8');
+  return Mojo::JSON::encode_json($_[1]);
+}
+
 sub _render_route_spec {
   my ($c, $path) = @_;
   my $spec   = $c->stash('openapi.api_spec')->data->{paths}{$path};
